@@ -4,10 +4,15 @@ from fastapi import FastAPI
 from fastapi.staticfiles import StaticFiles
 
 from . import globals
+from .native import Native
 
 
 class App(FastAPI):
 
+    def __init__(self, **kwargs) -> None:
+        super().__init__(**kwargs)
+        self.native = Native()
+
     def on_connect(self, handler: Union[Callable, Awaitable]) -> None:
         """Called every time a new client connects to NiceGUI.
 
@@ -38,6 +43,13 @@ class App(FastAPI):
         """
         globals.shutdown_handlers.append(handler)
 
+    def on_exception(self, handler: Union[Callable, Awaitable]) -> None:
+        """Called when an exception occurs.
+
+        The callback has an optional parameter of `Exception`.
+        """
+        globals.exception_handlers.append(handler)
+
     def shutdown(self) -> None:
         """Shut down NiceGUI.
 
@@ -59,6 +71,8 @@ class App(FastAPI):
         :param path: string that starts with a slash "/"
         :param directory: folder with static files to serve under the given path
         """
+        if path == '/':
+            raise ValueError('''Path cannot be "/", because it would hide NiceGUI's internal "/_nicegui" route.''')
         globals.app.mount(path, StaticFiles(directory=directory))
 
     def remove_route(self, path: str) -> None:
