@@ -10,6 +10,7 @@ class Colors(Element):
                  primary='#5898d4',
                  secondary='#26a69a',
                  accent='#9c27b0',
+                 dark='#1d1d1d',
                  positive='#21ba45',
                  negative='#c10015',
                  info='#31ccec',
@@ -22,8 +23,10 @@ class Colors(Element):
         self._props['primary'] = primary
         self._props['secondary'] = secondary
         self._props['accent'] = accent
+        self._props['dark'] = dark
         self._props['positive'] = positive
         self._props['negative'] = negative
         self._props['info'] = info
         self._props['warning'] = warning
+        self._props['key'] = self.id  # HACK: workaround for #600
         self.update()
