@@ -5,7 +5,7 @@ from .mixins.value_element import ValueElement
 
 class Expansion(ValueElement):
 
-    def __init__(self, text: str, *, icon: Optional[str] = None, value: bool = False) -> None:
+    def __init__(self, text: Optional[str] = None, *, icon: Optional[str] = None, value: bool = False) -> None:
         '''Expansion Element
 
         Provides an expandable container.
@@ -15,7 +15,8 @@ class Expansion(ValueElement):
         :param value: whether the expansion should be opened on creation (default: `False`)
         '''
         super().__init__(tag='q-expansion-item', value=value, on_value_change=None)
-        self._props['label'] = text
+        if text is not None:
+            self._props['label'] = text
         self._props['icon'] = icon
 
     def open(self) -> None:
