@@ -1,9 +1,12 @@
 from typing import Callable, Union
 
 from .. import globals
+from ..dependencies import register_component
 from ..element import Element
 from .mixins.text_element import TextElement
 
+register_component('link', __file__, 'link.js')
+
 
 class Link(TextElement):
 
@@ -19,10 +22,10 @@ class Link(TextElement):
         :param target: page function or string that is a an absolute URL or relative path from base URL
         :param new_tab: open link in new tab (default: False)
         """
-        super().__init__(tag='a', text=text)
+        super().__init__(tag='link', text=text)
         self._props['href'] = target if isinstance(target, str) else globals.page_routes[target]
         self._props['target'] = '_blank' if new_tab else '_self'
-        self._classes.extend(['underline', 'text-blue-500'])
+        self._classes = ['nicegui-link']
 
 
 class LinkTarget(Element):
