@@ -19,8 +19,8 @@ class Log(Element):
         super().__init__('log')
         self._props['max_lines'] = max_lines
         self._props['lines'] = ''
-        self.classes('border whitespace-pre font-mono')
-        self.style('opacity: 1 !important; cursor: text !important')
+        self._props['key'] = self.id  # HACK: workaround for #600
+        self._classes = ['nicegui-log']
         self.lines: deque[str] = deque(maxlen=max_lines)
 
     def push(self, line: Any) -> None:
@@ -28,3 +28,10 @@ class Log(Element):
         self.lines.extend(line.splitlines())
         self._props['lines'] = '\n'.join(self.lines)
         self.run_method('push', line)
+
+    def clear(self) -> None:
+        """Clear the log"""
+        super().clear()
+        self._props['lines'] = ''
+        self.lines.clear()
+        self.run_method('clear')
