@@ -9,4 +9,4 @@ class Row(Element):
         Provides a container which arranges its child in a row.
         '''
         super().__init__('div')
-        self.classes('row items-start gap-4')
+        self._classes = ['nicegui-row']
